==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa erróneo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, Vde. recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Produciuse un erro ao compartir %1$s porque este elemento xa está compartido coa conta %2$s",
    "Not allowed to create a federated share to the same account" : "Non está permitido crear unha compartición federada na mesma conta",
    "Federated shares require read permissions" : "As comparticións federadas precisan permisos de lectura",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar a compartición",
    "Federated sharing" : "Compartición federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vde. recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Vde. recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Federated Cloud Sharing" : "Compartición de nube federada",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartición federada de ficheiros",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Confirm data upload to lookup server" : "Confirmar o envío de datos ao servidor de busca",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Cando está activado, todas as propiedades da conta (p. ex., o enderezo de correo-e) co ámbito de visibilidade definido en «publicado», sincronizaranse automaticamente e transmitiranse a un sistema externo e estarán dispoñíbeis nun caderno de enderezos público e global.",
    "Disable upload" : "Desactivar o envío",
    "Enable data upload" : "Activar o envío de datos",
    "Confirm querying lookup server" : "Confirmar a consulta ao servidor de buscas",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Cando está activada, a entrada de busca ao crear comparticións enviarase a un sistema externo que fornece un caderno de enderezos público e global.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Isto utilízase para recuperar o ID de nube federado para facilitar a compartición federada.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ademais, poderánse enviar os enderezos de correo-e dos usuarios a ese sistema para verificalos.",
    "Disable querying" : "Desactivar a consulta",
    "Enable querying" : "Activar a consulta",
    "Unable to update federated files sharing config" : "Non é posíbel actualizar a configuración de uso compartido de ficheiros federados",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Axuste a forma como a xente pode compartir entre servidores. Isto inclúe tamén as comparticións entre persoas deste servidor se están a usaren a compartición federada.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle á xente deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
    "Allow people on this server to receive shares from other servers" : "Permitirlle á xente deste servidor recibir comparticións doutros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitirlle á xente deste servidor enviar comparticións a grupos noutros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitirlle á xente deste servidor recibir comparticións de grupos desde outros servidores",
    "The lookup server is only available for global scale." : "O servidor de buscas só está dispoñíbel a escala global.",
    "Search global and public address book for people" : "Buscar persoas nos cadernos de enderezos globais e públicos",
    "Allow people to publish their data to a global and public address book" : "Permitirlle á xente publicar os seus datos nun caderno de  enderezos global e público",
    "Trusted federation" : "Federación de confianza",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceptar automaticamente os recursos compartidos de contas e grupos federados de confianza de xeito predeterminado",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparta comigo a través do meu ID de nube federada de #Nextcloud, vexa {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparta comigo a través do meu ID de nube federada de #Nextcloud",
    "Share with me via Nextcloud" : "Comparta comigo a través de Nextcloud",
    "Cloud ID copied" : "Copiado o ID da nube",
    "Copy" : "Copiar",
    "Clipboard not available. Please copy the cloud ID manually." : "O portapapeis non está dispoñíbel. Copie o ID da nube manualmente.",
    "Copied!" : "Copiado!",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores {productName}, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com",
    "Your Federated Cloud ID" : "ID da súa nube federada",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con Vde.:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (anteriormente Twitter).",
    "formerly Twitter" : "anteriormente Twitter",
    "Mastodon" : "Mastodon",
    "Bluesky" : "Bluesky",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via {productName}" : "Comparta comigo a través de {productName}",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Remote share" : "Compartición remota",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} de {owner}@{remote}?",
    "Remote share password" : "Contrasinal da compartición remota",
    "Incoming share could not be processed" : "Non foi posíbel procesar a compartición entrante",
    "Cloud ID copied to the clipboard" : "O identificador de nube (Cloud ID) (foi copiado no portapapeis",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "Couldn't establish a federated share." : "Non foi posíbel estabelecer unha compartición federada",
    "Couldn't establish a federated share, maybe the password was wrong." : "Non foi posíbel estabelecer unha compartición federada, é probábel que o contrasinal sexa erróneo.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, Vde. recibirá unha notificación. Comprobe as súas notificacións.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  desde este servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Produciuse un erro ao compartir %1$s porque este elemento xa está compartido coa conta %2$s",
    "Not allowed to create a federated share to the same account" : "Non está permitido crear unha compartición federada na mesma conta",
    "Federated shares require read permissions" : "As comparticións federadas precisan permisos de lectura",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
    "Could not find share" : "Non foi posíbel atopar a compartición",
    "Federated sharing" : "Compartición federada",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Vde. recibiu {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Vde. recibiu {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Federated Cloud Sharing" : "Compartición de nube federada",
    "Sharing" : "Compartindo",
    "Federated file sharing" : "Compartición federada de ficheiros",
    "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
    "Confirm data upload to lookup server" : "Confirmar o envío de datos ao servidor de busca",
    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Cando está activado, todas as propiedades da conta (p. ex., o enderezo de correo-e) co ámbito de visibilidade definido en «publicado», sincronizaranse automaticamente e transmitiranse a un sistema externo e estarán dispoñíbeis nun caderno de enderezos público e global.",
    "Enable data upload" : "Activar o envío de datos",
    "Disable upload" : "Desactivar o envío",
    "Confirm querying lookup server" : "Confirmar a consulta ao servidor de buscas",
    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Cando está activada, a entrada de busca ao crear comparticións enviarase a un sistema externo que fornece un caderno de enderezos público e global.",
    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Isto utilízase para recuperar o ID de nube federado para facilitar a compartición federada.",
    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Ademais, poderánse enviar os enderezos de correo-e dos usuarios a ese sistema para verificalos.",
    "Enable querying" : "Activar a consulta",
    "Disable querying" : "Desactivar a consulta",
    "Unable to update federated files sharing config" : "Non é posíbel actualizar a configuración de uso compartido de ficheiros federados",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Axuste a forma como a xente pode compartir entre servidores. Isto inclúe tamén as comparticións entre persoas deste servidor se están a usaren a compartición federada.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle á xente deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
    "Allow people on this server to receive shares from other servers" : "Permitirlle á xente deste servidor recibir comparticións doutros servidores",
    "Allow people on this server to send shares to groups on other servers" : "Permitirlle á xente deste servidor enviar comparticións a grupos noutros servidores",
    "Allow people on this server to receive group shares from other servers" : "Permitirlle á xente deste servidor recibir comparticións de grupos desde outros servidores",
    "The lookup server is only available for global scale." : "O servidor de buscas só está dispoñíbel a escala global.",
    "Search global and public address book for people" : "Buscar persoas nos cadernos de enderezos globais e públicos",
    "Allow people to publish their data to a global and public address book" : "Permitirlle á xente publicar os seus datos nun caderno de  enderezos global e público",
    "Trusted federation" : "Federación de confianza",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Aceptar automaticamente os recursos compartidos de contas e grupos federados de confianza de xeito predeterminado",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparta comigo a través do meu ID de nube federada de #Nextcloud, vexa {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparta comigo a través do meu ID de nube federada de #Nextcloud",
    "Share with me via Nextcloud" : "Comparta comigo a través de Nextcloud",
    "Cloud ID copied" : "Copiado o ID da nube",
    "Copy" : "Copiar",
    "Clipboard not available. Please copy the cloud ID manually." : "O portapapeis non está dispoñíbel. Copie o ID da nube manualmente.",
    "Copied!" : "Copiado!",
    "Federated Cloud" : "Nube federada",
    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores {productName}, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com",
    "Your Federated Cloud ID" : "ID da súa nube federada",
    "Share it so your friends can share files with you:" : "Compártao para que as súas amizades poidan compartir ficheiros con Vde.:",
    "Bluesky" : "Bluesky",
    "Facebook" : "Facebook",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via {productName}" : "Comparta comigo a través de {productName}",
    "HTML Code:" : "Código HTML:",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "Remote share" : "Compartición remota",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} de {owner}@{remote}?",
    "Remote share password" : "Contrasinal da compartición remota",
    "Incoming share could not be processed" : "Non foi posíbel procesar a compartición entrante",
    "Cloud ID copied to the clipboard" : "O identificador de nube (Cloud ID) (foi copiado no portapapeis",
    "Copy to clipboard" : "Copiar no portapapeis.",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com",
    "X (formerly Twitter)" : "X (anteriormente Twitter).",
    "formerly Twitter" : "anteriormente Twitter"
},
"nplurals=2; plural=(n != 1);");
